package
Version:
v1.1.2-0...-5d0101c
Opens a new window with list of versions in this module.
Published: Oct 7, 2024
License: MIT
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func (server *Server) SetIntervalUpdateFunc(f func(i int64))
Source Files
¶
Click to show internal directories.
Click to hide internal directories.